/******************************************************************************
*
* project name:    TIGCC Tools Suite 
* file name:       ttebkgen.c
* initial date:    24/08/2000
* authors:         thomas.nussbaumer@gmx.net 
* description:     executes all steps till a complete eBook
*
* $Id: ttebkgen.c,v 1.4 2000/10/01 15:06:13 Thomas Nussbaumer Exp $
*
******************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>

#include "../include/tt.h"          // generic defines 
#include "../include/ttversion.h"   // tigcc tools suite version info
#include "../include/revtools.h"    // automatic cvs version extraction

#ifdef CVS_FILE_REVISION
#undef CVS_FILE_REVISION
#endif
//-----------------------------------------------------------------------------
// DON'T EDIT THE NEXT DEFINE BY HAND! THIS IS DONE AUTOMATICALLY BY THE
// CVS SYSTEM !!!
//-----------------------------------------------------------------------------
#define CVS_FILE_REVISION "$Revision: 1.5 $"


//=============================================================================
// outputs usage information of this tool
//=============================================================================
void PrintUsage() {    
    fprintf(stderr, "Usage: ttebkgen [-keepfiles] [-t <titlefile>] <infile> <varname> \"description\"\n\n"\
                    "the infile must contain the complete text of the final ebook.\n"\
                    "split points must be marked within the inputfile with tag\n"\
                    "<--split--> on a single line.\n"\
                    "NOTES:\n"\
                    " (1) the maximum uncompressed size of a ebook part is 65518 bytes.\n"\
                    " (2) the final size of the ebook cannot extend 65608 bytes\n"\
                    "     (including PC header infos)\n"\
                    " (3) if a part is too long, define more splitpoints in the infile\n"\
                    " (4) if the complete text will not fit into one ebook, split\n"\
                    "     the text into two or more ebooks\n"\
                    " (5) varname is used as outfile name and as varname on the calculator\n"\
                    " (6) don't forget to enclose the description in quotes !!\n"\
                    " (7) just the first 19 character of the description are used\n"\
                    " (8) both versions (ti89 and ti92p) are generated automatically\n"\
                    " (9) the inputfile will be copied to file tictinput before processing\n"\
                    "(11) titlefile must be a 4-grayscale pic with 160x100 pixels in binary form\n"\
                    "     generated with ImageStudio (not compressed binary)\n"\
                    "(12) don't name any of your files with prefix tictinput!\n" \
                    "(13) don't name any of your files pXXX.pck where XXX is an 3 digit integer!\n" \
                    "(14) don't use extension pck for your files!\n\n");
}


char* tmptitlename = "tt_tf00.bin";
char* titlename    = 0;

unsigned char default_image[] = {
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xff,0xff,0xfe,
0x00,0x00,0x00,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xff,0xff,0xfe,
0x00,0x00,0x00,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1e,0x00,0x00,0x00,0x0e,
0x00,0x7f,0xff,0x80,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1e,0xff,0xff,0xff,0xef,
0xff,0xf7,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1e,0xcf,0xff,0xfc,0xef,
0xff,0xff,0xfb,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1e,0xbf,0xff,0xff,0xef,
0xf0,0x03,0xfc,0x00,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1e,0xff,0xff,0xff,0xaf,
0xf0,0x03,0xfc,0x00,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1e,0x7f,0xc0,0x7f,0xce,
0x70,0x03,0xff,0xf0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1e,0xff,0xc0,0x7f,0xce,
0x70,0x03,0xff,0xe0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xce,
0x70,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xfe,
0x70,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xfe,
0x70,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xfe,
0x70,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xfe,
0x70,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xfe,
0x70,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xfe,
0x70,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xff,
0xf0,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xff,
0xf0,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xff,
0xf0,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xff,
0xf0,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xff,
0xf0,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xff,
0xf0,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xff,
0xf0,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xff,
0xf0,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xff,
0xf0,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xff,
0xf0,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xff,
0xf0,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xff,
0xf0,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xff,
0xf0,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xff,
0xf0,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xff,
0xf0,0x03,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xff,
0xf0,0x07,0xfb,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x7f,0xff,
0xf0,0x07,0xff,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xfc,0x1f,0xff,
0xf0,0x7f,0xff,0x80,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xff,0xff,0xff,
0xf0,0x00,0x1f,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xff,0xff,0xff,
0xf0,0x00,0x1f,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xff,0xff,0xff,
0xf0,0x00,0x1f,0xc0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xff,0xff,0xff,
0xf0,0x00,0x3f,0xe0,0x63,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xff,0x80,0x00,0x1f,
0xff,0xff,0xff,0xff,0xe3,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xe3,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xe3,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xff,0xd7,0xd7,0xef,
0xff,0xff,0xff,0xff,0xe3,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xff,0x7f,0xfc,0xdf,
0xf0,0x00,0x00,0x00,0xe3,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xc1,0xfc,0xef,0xb9,
0xef,0xff,0xff,0xfe,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xc7,0xf0,0x07,0xf9,
0xec,0xff,0xff,0xce,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xdf,0xe0,0x00,0xf9,
0xeb,0xff,0xff,0xfe,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xff,0xc0,0x00,0xf9,
0xef,0xff,0xff,0xfa,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xff,0x81,0xff,0xf9,
0xe7,0xfc,0x07,0xfc,0xe7,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x7f,0x87,0xc0,0x39,
0xef,0xfc,0x07,0xfc,0xe7,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x7f,0x1f,0x80,0x1f,
0xff,0xff,0xc7,0xfc,0xe7,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xfe,0x7e,0x00,0x1f,
0xff,0xff,0xc7,0xff,0xe7,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x19,0xfe,0xfc,0x00,0x1b,
0xff,0xff,0xc7,0xff,0xe7,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x19,0xff,0xf8,0x00,0x01,
0xff,0xff,0xc7,0xff,0xe7,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x19,0xff,0xf8,0x00,0x01,
0xff,0xff,0xc7,0xff,0xe7,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1b,0xfd,0xf0,0x00,0x01,
0xff,0xff,0xc7,0xff,0xe7,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1b,0xff,0xf0,0x00,0x01,
0xff,0xff,0xc7,0xff,0xe7,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1b,0xff,0xf0,0x00,0x01,
0xff,0xff,0xc7,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xe0,0x00,0x01,
0xff,0xff,0xc7,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xe0,0x00,0x01,
0xff,0xff,0xc7,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xe0,0x00,0x01,
0xff,0xff,0xc7,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xfd,0xe0,0x00,0x01,
0xff,0xff,0xc7,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1b,0xfd,0xe0,0x00,0x01,
0xff,0xff,0xc7,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1b,0xff,0xe0,0x00,0x01,
0xff,0xff,0xc7,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x19,0xff,0xe0,0x00,0x01,
0xff,0xff,0xc7,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x19,0xfe,0xe0,0x00,0x01,
0xff,0xff,0xc7,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x19,0xff,0xe0,0x00,0x01,
0xff,0xff,0xc7,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x19,0xff,0xe0,0x00,0x01,
0xff,0xff,0xc7,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xff,0x60,0x00,0x21,
0xff,0xff,0xc7,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x7f,0xe0,0x00,0x61,
0xff,0xff,0xc7,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xff,0xf0,0x00,0xe1,
0xff,0xff,0xc7,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xff,0xf0,0x01,0xc1,
0xff,0xff,0xc7,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xcf,0xe0,0x07,0xc1,
0xff,0xff,0xc7,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xc3,0xfd,0xcf,0x01,
0xff,0xff,0xc7,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xc2,0xff,0xfe,0x01,
0xff,0xff,0xc1,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xc1,0xa7,0xd0,0x03,
0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xc0,0xfe,0x00,0x07,
0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x03,0xff,0xc0,
0x0f,0xf8,0x00,0x01,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,
0x0f,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xc0,0x00,0x00,0x00,
0x0f,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x03,0x80,0x00,
0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x7c,0x00,0x00,0x70,0x07,0xc0,0x00,
0x1f,0xef,0x1e,0x1e,0x03,0x9e,0x1e,0x00,0x00,0x00,
0x00,0x00,0x00,0x7e,0x00,0x00,0x70,0x07,0x00,0x00,
0x0f,0xf7,0xbf,0x3f,0x07,0xbf,0x3f,0x04,0x00,0x00,
0x00,0x00,0x3c,0x77,0x3c,0x3c,0x76,0x0f,0x9e,0x36,
0x03,0x87,0x3b,0xbb,0x87,0x3b,0x9b,0x86,0x00,0x00,
0x00,0x00,0x7e,0x7f,0x7e,0x7e,0x7f,0x07,0xff,0x3f,
0x03,0x87,0x1f,0xbb,0x8f,0x3b,0x87,0x86,0x00,0x00,
0x00,0x00,0x7f,0x7e,0x77,0x77,0x7e,0x07,0x3b,0xbf,
0x03,0x87,0x3f,0x1f,0x8e,0x1f,0x8f,0x3f,0x80,0x00,
0x00,0x00,0x7f,0x77,0x77,0x77,0x7c,0x07,0x3b,0xb8,
0x03,0x87,0x3b,0x8f,0x8e,0x0f,0x9e,0x1f,0xc0,0x00,
0x00,0x00,0x72,0x77,0x77,0x77,0x7c,0x07,0x3b,0xb8,
0x03,0x87,0x3b,0x87,0x9e,0x07,0xbc,0x06,0x00,0x00,
0x00,0x00,0x3d,0x7f,0x3f,0x3f,0x76,0x07,0x1f,0xb8,
0x03,0x8f,0x1f,0x9f,0x1c,0x1f,0x3f,0x06,0x00,0x00,
0x00,0x00,0x1e,0x3e,0x1e,0x1e,0x33,0x03,0x0f,0x18,
0x01,0x87,0x8f,0x0e,0x3c,0x0e,0x1f,0x82,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x38,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x18,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xff,0xff,0xfe,
0x00,0x00,0x00,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xff,0xff,0xfe,
0x00,0x00,0x00,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1e,0x00,0x00,0x00,0x1e,
0x00,0x7f,0xff,0xc0,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1e,0x00,0x00,0x00,0x1e,
0x00,0x0f,0xfc,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1e,0x1f,0x80,0x7e,0x1e,
0x00,0x07,0xfc,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1e,0x3f,0x80,0x7f,0x1e,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1e,0x7f,0x80,0x7f,0x9e,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1e,0xff,0x80,0x7f,0xde,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1e,0xff,0x80,0x7f,0xde,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1e,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xf8,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x80,0x7f,0xfe,
0x00,0x07,0xfc,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0x00,0x3f,0xfe,
0x00,0x0f,0xfc,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xf8,0x00,0x07,0xfe,
0x00,0x7f,0xff,0xc0,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xff,0xff,0xfe,
0x00,0x00,0x00,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xff,0xff,0xfe,
0x00,0x00,0x00,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xff,0xff,0xfe,
0x00,0x00,0x00,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xff,0xff,0xfe,
0x00,0x00,0x00,0x00,0x60,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x00,0x00,0x00,0x01,
0xff,0xff,0xff,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x00,0x00,0x00,0x01,
0xff,0xff,0xff,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x00,0x00,0x00,0x01,
0xff,0xff,0xff,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x00,0x0f,0xe0,0x11,
0xff,0xff,0xff,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x00,0xff,0xfe,0x11,
0xe0,0x00,0x00,0x01,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x03,0xff,0x1f,0xf1,
0xe0,0x00,0x00,0x01,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x07,0xf8,0x03,0xf1,
0xe1,0xf8,0x07,0xe1,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x0f,0xe0,0x01,0xf1,
0xe3,0xf8,0x07,0xf1,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x1f,0xc0,0x00,0x71,
0xe7,0xf8,0x07,0xf9,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x3f,0x80,0x00,0x71,
0xef,0xf8,0x07,0xfd,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x7f,0x00,0x00,0x31,
0xef,0xf8,0x07,0xfd,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xff,0x00,0x00,0x31,
0xef,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xff,0x00,0x00,0x11,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x19,0xfe,0x00,0x00,0x11,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x19,0xfe,0x00,0x00,0x01,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1b,0xfe,0x00,0x00,0x01,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1b,0xfe,0x00,0x00,0x01,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1b,0xfc,0x00,0x00,0x01,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1b,0xfc,0x00,0x00,0x01,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1b,0xfc,0x00,0x00,0x01,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1b,0xfc,0x00,0x00,0x01,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1b,0xfc,0x00,0x00,0x01,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1b,0xfe,0x00,0x00,0x01,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1b,0xfe,0x00,0x00,0x01,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1b,0xfe,0x00,0x00,0x01,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1b,0xfe,0x00,0x00,0x01,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x19,0xfe,0x00,0x00,0x01,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x19,0xfe,0x00,0x00,0x01,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xff,0x00,0x00,0x01,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0xff,0x00,0x00,0x11,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x7f,0x80,0x00,0x31,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x3f,0x80,0x00,0x71,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x1f,0xc0,0x00,0xe1,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x0f,0xf0,0x03,0x81,
0xff,0xf8,0x07,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x07,0xfe,0x3f,0x01,
0xff,0xf0,0x03,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x01,0xff,0xfc,0x01,
0xff,0x80,0x00,0x7f,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x00,0x1f,0xe0,0x01,
0xff,0xff,0xff,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x18,0x00,0x00,0x00,0x01,
0xff,0xff,0xff,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xe0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x03,0x80,0x00,
0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x7c,0x00,0x00,0x60,0x06,0x00,0x00,
0x1f,0xef,0x1e,0x1e,0x03,0x1e,0x1e,0x00,0x00,0x00,
0x00,0x00,0x00,0x66,0x00,0x00,0x60,0x06,0x00,0x00,
0x03,0x06,0x33,0x33,0x06,0x33,0x33,0x04,0x00,0x00,
0x00,0x00,0x3c,0x66,0x3c,0x3c,0x66,0x0f,0x9e,0x36,
0x03,0x06,0x33,0x33,0x06,0x33,0x03,0x04,0x00,0x00,
0x00,0x00,0x66,0x7c,0x66,0x66,0x6c,0x06,0x33,0x3e,
0x03,0x06,0x1e,0x33,0x0c,0x33,0x06,0x04,0x00,0x00,
0x00,0x00,0x7e,0x66,0x66,0x66,0x78,0x06,0x33,0x30,
0x03,0x06,0x33,0x1f,0x0c,0x1f,0x0c,0x3f,0x80,0x00,
0x00,0x00,0x60,0x66,0x66,0x66,0x78,0x06,0x33,0x30,
0x03,0x06,0x33,0x03,0x0c,0x03,0x18,0x04,0x00,0x00,
0x00,0x00,0x62,0x66,0x66,0x66,0x6c,0x06,0x33,0x30,
0x03,0x06,0x33,0x06,0x18,0x06,0x30,0x04,0x00,0x00,
0x00,0x00,0x3c,0x7c,0x3c,0x3c,0x66,0x06,0x1e,0x30,
0x03,0x0f,0x1e,0x1c,0x18,0x1c,0x3f,0x04,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x30,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x30,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00};


//=============================================================================
// outputs a message with a special prefix
//=============================================================================
void OutMsg(char*s) {
    fprintf(stderr,"\n\n[##ttebkgen##] %s\n\n",s);
}


//=============================================================================
// delete temporary files
//=============================================================================
void CleanUp(int keepfiles) {
    int i;
    char tmpname[100];
    
    if (!keepfiles) {
        for (i=0;i<1000;i++) {
            sprintf(tmpname,"tictinputp%03d",i);
            if (remove(tmpname)) break;
        }
        for (i=0;i<1000;i++) {
            sprintf(tmpname,"p%03d.pck",i);
            if (remove(tmpname)) break;
        }
        for (i=0;i<1000;i++) {
            sprintf(tmpname,"tictinputp%03d.pck",i);
            if (remove(tmpname)) break;
        }
        for (i=0;i<1000;i++) {
            sprintf(tmpname,"tictinputp%03d.ebk",i);
            if (remove(tmpname)) break;
        }

        remove("tictinput");
        remove("tictinput.cfg");
        remove("title.pck");
        
        if (tmptitlename == titlename) remove(tmptitlename);
    }
}


//=============================================================================
// copies files
//=============================================================================
int FileCopy(char* source, char* dest) {
    FILE* fp_src = fopen(source,"rb");
    FILE* fp_dest;
    int   c;

    if (!fp_src) return 0;

    if (!(fp_dest = fopen(dest,"wb"))) {
        fclose(fp_src);
        return 0;
    }

    do {
        c = fgetc(fp_src);
        if (c == EOF) break;
        fputc(c,fp_dest);
    }
    while (1);
    
    fclose(fp_src);
    fclose(fp_dest);

    return 1;
}


//=============================================================================
// a main is a main is main .....
//=============================================================================
int main(int argc, char* argv[]) {
    char* infilename  = 0;
    char* varname     = 0;
    char* description = 0;
    FILE* fp;
    char  buffer[1024];
    char  tmpname[1024];
    int   i;
    int   count;
    int   keep = 0;
    
    PRINT_ID("TTEbkGen");

    if (argc < 4) {
        PrintUsage();
        return 1;
    }

    // parse arguments
    for (i=1; i<argc; i++) {
        if (!strcmp(argv[i], "-keepfiles")) keep = 1;
        else if (!strcmp(argv[i], "-t")) {
            if (i == argc-1) {
                PrintUsage();
                return 1;
            }
            i++;
            titlename = argv[i];
        }
        else if (!infilename)  infilename  = argv[i];
        else if (!varname)     varname     = argv[i];
        else if (!description) description = argv[i];
        else {
            PrintUsage();
            return 1;
        }
    }


    if (!infilename || !varname || !description) {
        PrintUsage();
        return 1;
    }

    CleanUp(0); // delete old files to make sure we won't process them


    //--------------------------------------------
    // if no title file is given, generate default
    // title file
    //--------------------------------------------
    if (!titlename) {
        FILE *f;
        titlename = tmptitlename;

        if (!(f = fopen(titlename,"wb"))) {
            fprintf(stderr,"ERROR: cannot generate temporary titlefile %s\n",titlename);
            return 1;
        }
        if (fwrite(default_image,4000,1,f) != 1) {
            fprintf(stderr,"ERROR: cannot generate temporary titlefile %s\n",titlename);
            return 1;
        }
        fclose(f);
    }


    //--------------------------------------------------------
    // check if files exists and if title file is of size 4000
    //--------------------------------------------------------
    if (!(fp=fopen(infilename,"r"))) {
        fprintf(stderr,"ERROR: infile %s doesn't exists\n",infilename);
        CleanUp(keep);
        return 1;
    }
    fclose(fp);

    if (!(fp=fopen(titlename,"rb"))) {
        fprintf(stderr,"ERROR: titlefile %s doesn't exists\n",titlename);
        CleanUp(keep);
        return 1;
    }
    fseek(fp,0,SEEK_END);
    if (ftell(fp) != 4000) {
        fprintf(stderr,"ERROR: titlefile %s is not of size 4000\n",titlename);
        fclose(fp);
        CleanUp(keep);
        return 1;
    }        
    fclose(fp);


    //--------------------------------------------------------
    // copy inputfile  
    //--------------------------------------------------------
    OutMsg("copying now inputfile .....");
    if (!FileCopy(infilename,"tictinput")) {
        CleanUp(keep);
        return 1;
    }
    
    //--------------------------------------------------------
    // splitting
    //--------------------------------------------------------
    OutMsg("splitting inputfile .....");
    sprintf(buffer,"ttsplit -s \"<--split-->\" -t tictinput");
    if (system(buffer)) {
        CleanUp(keep);
        return 1;
    }

    //--------------------------------------------------------
    // converting now files
    //--------------------------------------------------------
    OutMsg("converting now parts .....");

    for (i=0;i<1000;i++) {
        sprintf(tmpname,"tictinputp%03d",i);
        fp = fopen(tmpname,"r");
        if (!fp) break;
        fclose(fp);

        sprintf(buffer,"ttdos2ebk %s %s.ebk",tmpname,tmpname);
        if (system(buffer)) {
            CleanUp(keep);
            return 1;
        }
    }
    
    count = i;
    if (count == 0) {    
        fprintf(stderr,"ERROR: no data to process further\n");
        CleanUp(keep);
        return 1;
    }
    
    //--------------------------------------------------------
    // compressing files
    //--------------------------------------------------------
    OutMsg("compressing now title and parts .....");

    sprintf(buffer,"ttpack %s title.pck",titlename);
    if (system(buffer)) {
        CleanUp(keep);
        return 1;
    }

    for (i=0;i<count;i++) {
        sprintf(buffer,"ttpack tictinputp%03d.ebk p%03d.pck",i,i);
        if (system(buffer)) {
            CleanUp(keep);
            return 1;
        }
    }
   
    //--------------------------------------------------------
    // generating ebook
    //--------------------------------------------------------
    OutMsg("generatic ebook .....");

    fp = fopen("tictinput.cfg","w");

    if (!fp) {
        fprintf(stderr,"ERROR: cannot generate tictbook.cfg\n");
        CleanUp(keep);
        return 1;
    }

    fprintf(fp,"#%s\n",description);
    fprintf(fp,"title.pck title 0 0\n");
    
    for (i=0;i<count;i++) fprintf(fp,"p%03d.pck p%03d 0 0\n",i,i);    
    fclose(fp);
    
    sprintf(buffer,"ttarchive -89 -e ebk tictinput.cfg %s tictebks",varname);
    if (system(buffer)) {
        CleanUp(keep);
        return 1;
    }
   
    sprintf(buffer,"ttbin2bin %s.89y",varname);
    if (system(buffer)) {
        CleanUp(keep);
        return 1;
    }

    sprintf(buffer,"eBook %s.89y and eBook %s.9xy sucessfully generated.",varname,varname);
    OutMsg(buffer);
    CleanUp(keep);
    return 0;
}

//#############################################################################
//###################### NO MORE FAKES BEYOND THIS LINE #######################
//#############################################################################
//
//=============================================================================
// Revision History
//=============================================================================
//
// $Log: ttebkgen.c,v $
// Revision 1.4  2000/10/01 15:06:13  Thomas Nussbaumer
// using now default title image if none is specified
//
// Revision 1.3  2000/08/26 19:07:09  Thomas Nussbaumer
// using now inline split tag (much easier to handle than an external splitfile)
//
// Revision 1.2  2000/08/25 18:10:33  Thomas Nussbaumer
// some corrections to usage text
//
// Revision 1.1  2000/08/25 18:06:30  Thomas Nussbaumer
// initial version
//
//
//
